from setuptools import setup

setup(name='lagoons_distributions',
      version='0.1',
      description='Probability distributions',
      packages=['lagoons_distributions'],
      author = "Harris Ramos Baroni",
      author_email = "yuopres@gmail.com",
      zip_safe=False)
